@@ -2,10 +2,10 @@ __author__ = "Kura"
 __copyright__ = "None"
 __credits__ = ["Kura", ]
 __license__ = "BSD 3-Clause"
-__version__ = "1.3.7"
+__version__ = "1.3.8"
 __maintainer__ = "Kura"
 __email__ = "kura@kura.io"
-__status__ = "Beta"
+__status__ = "Stable"
 
 __pname__ = "blackhole"
 __desc__ = "blackhole.io MTA"
